@@ -30,7 +30,7 @@ from .exceptions import (
 class MemoryStackClient:
     """Client for interacting with MemoryStack API"""
     
-    SDK_VERSION = "1.0.0"
+    SDK_VERSION = "1.0.2"
 
     def __init__(
         self,
@@ -73,7 +73,7 @@ class MemoryStackClient:
         
         # Use default production URL if not provided
         if not base_url:
-            base_url = "https://memorystack.app"
+            base_url = "https://www.memorystack.app"
         
         # Normalize base URL
         base_url = base_url.strip()
@@ -110,6 +110,7 @@ class MemoryStackClient:
         self.session.headers.update({
             "Content-Type": "application/json",
             "Authorization": f"Bearer {api_key}",
+            "X-API-Key": api_key,  # Fallback for environments that strip Authorization header
             "X-SDK-Version": self.SDK_VERSION,
             "User-Agent": f"memorystack-python-sdk/{self.SDK_VERSION}",
         })
